#!/bin/sh
#
#

buildpkg ()
{
	echo "Building package: ${PKGNAME}"
	rm -f ../packages/${PKGNAME}.lrp 2>&1 > /dev/null
	cd $PKGNAME
	tar -cf ../../packages/${PKGNAME}.tar *
	cd ../../packages
	gzip -9 ${PKGNAME}.tar
	mv ${PKGNAME}.tar.gz ${PKGNAME}.lrp
	cd ../pkgsrc
}


buildall()
{

cd pkgsrc

for PKGNAME in `ls`; do 
	buildpkg
done

cd ..

}

set_deps() {

echo
echo "Checking module dependencies..."
for MODLIST in `cat data/netmods.txt`; do
	if [ "`echo $MODLIST | cut -d "," -f 1`" = "$NETMOD1" ]; then
		MODDEP1=`echo $MODLIST | cut -d "," -f 2`
		if ! [ -z "$MODDEP1" ]; then
			echo "$NETMOD1 deps = $MODDEP1"
		else
			echo "$NETMOD1 deps = none"
		fi 
	fi			
	if [ "`echo $MODLIST | cut -d "," -f 1`" = "$NETMOD2" ]; then
		MODDEP2=`echo $MODLIST | cut -d "," -f 2`
		if ! [ -z "$MODDEP2" ]; then
			echo "$NETMOD2 deps = $MODDEP1"
		else
			echo "$NETMOD2 deps = none"
		fi 
	fi			
done
echo

}

check_yn() {

YN=""

while [ "$YN" = "" ]; do
	echo -n $YNMSG
	read YN
	[ "$YN" = "y" ] && YN="Y"
	[ "$YN" = "n" ] && YN="N"
	[ "$YN" = "Y" ] || [ "$YN" = "N" ] || YN=""
done

}

echo
echo
echo "FrazierWall floppy builder script v1.0"
echo

if ! [ "$UID" = "0" ]; then
	echo "You should be logged in as root to create the FrazierWall floppy disk. Non-root users"
	echo "can experience permission problems under some distributions when attempting to"
	echo "access the floppy drive.  To cancel, press CTRL-C... to proceed, press enter"
	read JUNK
fi

if [ -f floppy/dhcpd.lrp ]; then
	rm -f floppy/dhcpd.lrp
fi

if [ -f floppy/rrlogind.lrp ]; then
	rm -f floppy/rrlogind.lrp
fi

YNMSG="Does your Internet connection get its IP via DHCP? [y/n]: "
check_yn
if [ "$YN" = "Y" ]; then
	USEDHCP=YES
else
	USEDHCP=NO
	echo
	echo "Please enter the information for your static IP configuration"
	echo -n "Internet IP Address: "
	read IPADDR
	echo -n "Internet Subnet Mask [255.255.255.0]: "
	read NETMASK
	# If the user did not specify a subnet mask, default to a Class C
	[ -z "$NETMASK" ] && NETMASK=255.255.255.0
	echo -n "Internet Broadcast [Enter = Default]: "
	read BROADCAST
	echo -n "Internet Gateway Address: "
	read GATEWAY
	echo -n "Domain Name: "
	read DOMAINNAME
	echo "DNS Server 1: "
	read DNS1
	echo "DNS Server 2 (optional): "
	read DNS2
fi

# Clear the additional packages file
echo > pkgsrc/config/etc/frazierwall/packages

echo
YNMSG="Install the Road Runner DEC protocol login software [y/n]: "
check_yn
if [ "$YN" = "Y" ]; then
	ln -s ../packages/rrlogind.lrp floppy/rrlogind.lrp
	echo "rrlogind" >> pkgsrc/config/etc/frazierwall/packages
	USERRM=YES
	echo
	echo "You will need to set your login and password information from"
	echo "the FrazierWall main menu after booting from the floppy for the first"
	echo "time.  Be sure to use the backup configuration option afer you"
	echo "have configured rrlogind"
else
	USERRM=NO
fi

echo
YNMSG="Do you want to enable the FrazierWall DHCP server [y/n]: "
check_yn
if [ "$YN" = "Y" ]; then
	ln -s ../packages/dhcpd.lrp floppy/dhcpd.lrp
	echo "dhcpd" >> pkgsrc/config/etc/frazierwall/packages
	DHCP_SERVER=YES
else
	DHCP_SERVER=NO
fi

echo
echo "Some areas require you to specify a hostname when obtaining and DHCP address."
echo "This hostname would have been given to you when you originally signed got"
echo "your Internet access installed.  To date, the @home network is the only ISP"
echo "that I know of that sets clients up in this fashion.  If you have been"
echo "supplied with a hostname for your computer, enter it here... otherwise"
echo "simply press enter."
echo
echo -n "Enter your DHCP hostname: "
read DHCPHOSTNAME

echo
echo "You now need to specify the name of the network card modules, as well as"
echo "any parameters that are required for each card.  For example, the NE2000"
echo "ISA driver requires an IO address and IRQ.  These are specified as"
echo "follows:  ne io=0x300 irq=10"
echo
echo "NOTE: If the card that you are specifying is a PCI or EISA card, there is"
echo "      no need to specify a port and IRQ.  Simple specify the name of the"
echo "      module."
echo
echo -n "Module name and params for your Internet network card: "
read CARD1
#check_empty $CARD1
echo -n "Module name and params for your local network card: "
read CARD2
#check_empty $CARD2

# Reset the modules definition file
cp data/modules pkgsrc/modules/etc
# Reset the modules directory
rm -f pkgsrc/modules/lib/modules/*
for REQMODS in `cat data/modules`; do
	cp drivers/$REQMODS.o pkgsrc/modules/lib/modules/
done

# Copy the needed modules into place
NETMOD1=`echo $CARD1 | cut -d " " -f 1`
NETMOD2=`echo $CARD2 | cut -d " " -f 1`

# Set any module dependencies
set_deps

# Install necessary dep modules
if ! [ -z "$MODDEP1" ]; then
	if ! [ -f drivers/$MODDEP1.o ]; then
		echo "Unable to copy dep modules for card1 ($MODDEP1)"
		exit 1
	fi
	cp drivers/$MODDEP1.o pkgsrc/modules/lib/modules/
	echo "$MODDEP1" >> pkgsrc/modules/etc/modules
elif ! [ -z "$MODDEP2" ]; then
	if ! [ -f drivers/$MODDEP2.o ]; then
		echo "Unable to copy dep modules for card2 ($MODDEP2)"
		exit 1
	fi
	cp drivers/$MODDEP2.o pkgsrc/modules/lib/modules/
	echo "$MODDEP2" >> pkgsrc/modules/etc/modules
fi	


# Install the Internet card driver
if ! [ -f drivers/$NETMOD1.o ]; then
	echo "Unable to copy driver module for card1 ($NETMOD1)"
	exit 1
fi
cp drivers/$NETMOD1.o pkgsrc/modules/lib/modules/
echo "$CARD1" >> pkgsrc/modules/etc/modules

# If the same module string was specified, dont install it twice
if ! [ "$CARD1" = "$CARD2" ]; then
	# Install local card driver
	if ! [ -f drivers/$NETMOD2.o ]; then
		echo "Unable to copy driver module for card2 ($NETMOD2)"
		exit 1
	fi
	cp drivers/$NETMOD2.o pkgsrc/modules/lib/modules/
	echo "$CARD2" >> pkgsrc/modules/etc/modules
fi

# Create the FrazierWall configuration file
echo "USERRM=$USERRM" > pkgsrc/config/etc/frazierwall/frazierwall.conf
echo "USEDHCP=$USEDHCP" >>  pkgsrc/config/etc/frazierwall/frazierwall.conf
if [ "$USEDHCP" = "NO" ]; then
	echo "IPADDR=$IPADDR" >>  pkgsrc/config/etc/frazierwall/frazierwall.conf
	echo "NETMASK=$NETMASK" >>  pkgsrc/config/etc/frazierwall/frazierwall.conf
	if ! [ -z "$BROADCAST" ]; then 
		echo "BROADCAST=$BROADCAST" >> pkgsrc/config/etc/frazierwall/frazierwall.conf
	fi
	echo "GATEWAY=$GATEWAY" >>  pkgsrc/config/etc/frazierwall/frazierwall.conf
	echo "DNS1=$DNS1" >>  pkgsrc/config/etc/frazierwall/frazierwall.conf
	echo "DNS2=$DNS2" >>  pkgsrc/config/etc/frazierwall/frazierwall.conf
	echo "DOMAINNAME=$DOMAINNAME" >>  pkgsrc/config/etc/frazierwall/frazierwall.conf
fi
echo "DHCPSERVER=$DHCP_SERVER" >>  pkgsrc/config/etc/frazierwall/frazierwall.conf
if ! [ -z "$DHCPHOSTNAME" ]; then
	echo "DHCPHOSTNAME=$DHCPHOSTNAME" >> pkgsrc/config/etc/frazierwall/frazierwall.conf
fi

echo "Building packages..."
buildall

if [ "$1" = "-n" ]; then
	DMFMT=NO
	FLOPPY=/dev/fd0
else
	if [ -a /dev/fd0H1440 ]; then
		FLOPPY=/dev/fd0H1440
		DOFMT=YES
	elif [ -a /dev/fd0h1440 ]; then
		FLOPPY=/dev/fd0h1440
		DOFMT=YES
	else
		echo "Unable to find device /dev/fd0H1440 or /dev/fd0h1440... the drive can not"
		echo "be automatically formatted.  If the disk in the drive is already formatted"
		echo "with a FAT file system, press enter. If you need to cancel, press CTRL-C"
		FLOPPY=/dev/fd0
		DOFMT=NO
	fi
	if [ "$DOFMT" = "YES" ]; then
		PATH=$PATH:/sbin:/usr/sbin:/usr/local/sbin

		FDFMT=`which fdformat`
		MKFS=`which mkdosfs`
		if [ -z "$FDFMT" ]; then
			echo "Unable to find the fdformat command, the floppy can not be automatically formatted"
			echo "If the floppy is already formatted with a FAT file system, press enter. If you need"
			echo "to cancel, press CTRL-C"
			DOFMT=NO
		fi
		if [ -z "$MKFS" ]; then
			echo "Unable to find the mkdosfs command, the floppy can not be automatically formatted"
			echo "If the floppy is already formatted with a FAT file system, press enter. If you need"
			echo "to cancel, press CTRL-C"
			DMFMT=NO
		fi
	fi
fi

echo
echo "Make sure that you have a floppy in the first floppy drive"
echo "in this system and press enter to continue..."
read JUNK

if [ "$DOFMT" = "YES" ]; then
	echo "Formatting $FLOPPY"
#	$FDFMT $FLOPPY
	$MKFS -F 12 -v -n firewall $FLOPPY
fi

echo "Installing boot loader..."
syslinux/syslinux $FLOPPY
echo "Copying files..."
mcopy floppy/* a: -v
echo "Done."

